pub struct ResolvedDependency { /* private fields */ }Expand description
A resolved dependency contains information on the artifacts it stores and the downloaded files it refers to
Implementations
Sourceimpl ResolvedDependency
impl ResolvedDependency