pub struct ProjectFinder { /* private fields */ }Expand description
Finds a sub project.
Project Resolution
From a given base project, a path is resolved as follows:
- an empty path (
"") refers to the base project. - a path starting with a
":"searches starting from therootproject. - A path starting with
:<root project name>is equivalent to just":". - each component after that, which are seperated by a
":", is a child of the current search
For example, in this given structure with a search starting pointed marked with <--,
root:
- child1: <--
- child2:
- child3:To access child2, you can either use child2, :child1:child2, or :root:child1:child2.
Meanwhile, child3 can only be accessed via :child3, or :root:child3.
Implementations
Sourceimpl ProjectFinder
impl ProjectFinder
Sourcepub fn new(project: &SharedProject) -> Self
pub fn new(project: &SharedProject) -> Self
Creates a new project finder
Sourcepub fn find<S: AsRef<ProjectPath>>(&self, id: S) -> Option<SharedProject>
pub fn find<S: AsRef<ProjectPath>>(&self, id: S) -> Option<SharedProject>
Tries to find a project relative to this one from a project id.
For more info on how finding works, check out the definition of the ProjectFinder