TaskAction

Trait TaskAction 

pub trait TaskAction<T: Task>: Send {
    // Required method
    fn execute(
        &self,
        task: &mut Executable<T>,
        project: &Project,
    ) -> BuildResult<()>;
}
Represents some work that can be done by a task

Required Methods

fn execute( &self, task: &mut Executable<T>, project: &Project, ) -> BuildResult<()>

Executes the task action on some executable task along with it’s owning project.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, T> TaskAction<T> for F
where F: Fn(&mut Executable<T>, &Project) -> BuildResult + Send, T: Task,

Source

impl<T: Task> TaskAction<T> for Action<T>