pub trait TaskAction<T: Task>: Send {
// Required method
fn execute(
&self,
task: &mut Executable<T>,
project: &Project,
) -> BuildResult<()>;
}Expand description
Represents some work that can be done by a task
Required Methods
Sourcefn execute(
&self,
task: &mut Executable<T>,
project: &Project,
) -> BuildResult<()>
fn execute( &self, task: &mut Executable<T>, project: &Project, ) -> BuildResult<()>
Executes the task action on some executable task along with it’s owning project.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".